<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

/**
 * Represents a feedback provided by a user about an evidence : true detection
 * or false alarm.
 */
class Feedback extends Model
{
    /**
     * The storage format of the model's date columns.
     *
     * @var string
     */
    protected $dateFormat = 'U';

    public function user()
    {
        return $this->belongsTo(\App\User::class);
    }

    public function timeForHumans() : string
    {
        return $this->created_at->toISOString();
    }

    public function badge() : string
    {
        if ($this->is_true_alert) {
            return '<span class="badge badge-warning">True detection</span>';
        } else {
            return '<span class="badge badge-success">False alert</span>';
        }
    }

    public function report() : \Cylab\Mark\Evidence
    {
        return Mark::get()->findEvidenceById($this->report_id);
    }

    public static function findByReportId(string $id)
    {
        return self::where("report_id", $id)->first();
    }
}
